/*
 * SPDX-FileCopyrightText: 2019-2022 Badwolf Authors <https://hacktivis.me/projects/badwolf>
 * SPDX-License-Identifier: BSD-3-Clause
 */

#browser__location, #browser__statuslabel, #browser__tabbox__context_label { font-family: monospace; }
button:checked label { font-weight: bold; }
